@@ -1024,7 +1024,9 @@ static int parse_one_config(const char *filename)
 
   /* if param is config file (.cfg file) */
   
-  if(strlen(filename)>4 && !strcmp(filename+strlen(filename)-4,".cfg")) {
+  if(strlen(filename)>4 && !strcmp(filename+strlen(filename)-4,".cfg") ||
+       strlen(filename)>5 && !strcmp(filename+strlen(filename)-5,".conf") ||
+       strlen(filename)>12 && !strncmp(filename,"pxelinux.cfg",12) ) {
       f = fopen(filename, "r");
       if( !f )
         if( startconfig[0] ) {
